==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/sluzebnicesty/f_sluzebnicesta.php <==
<?php
/**
 * UTF8
 * stanislav.elbl, 02.03.2017
 */

namespace Ron\RonPortal;

use Ron\Controls\ComboBox;
use Ron\Controls\Option;
use Ron\DB\Database;
use Ron\MessageManager;
use Ron\MVC\BaseViewObject;
use Ron\MVC\Model;
use RonPortal\SluzebniCesty\SluzebniCesta;

require_once('ron/controls.php');

class SluzebniCestaFormular extends BaseViewObject
{
    /** @var Database */
    public $database;

    /** @var SluzebniCesta */
    public $sluzebniCesta;

    /** @var string */
    public $formAction;

    /** @var Option[] */
    public $menyOptions;

    /** @var Option[] */
    public $pocatkySC;
    /** @var Option[] */
    public $cileSC;
    /** @var Option[] */
    public $statySC;
    /** @var Option[] */
    public $ucelySC;
    /** @var Option[] */
    public $dopravniProstredky;
    /** @var Option[] */
    public $vozidla;

    /** @var Option[] */
    public $zpusobyUctovani;

    /** @var ComboBoxZamestnanec */
    public $comboBoxOsoba;

    /** @var ComboBoxesRozdeleni */
    public $comboBoxesRozdeleni;

    /** @var TypRozdeleni */
    public $typRozdeleni;


    /**
     * SluzebniCestaFormular constructor.
     * @param Database $database
     * @param SluzebniCesta $sluzebniCesta
     * @param string $action
     */
    public function __construct(Database $database, SluzebniCesta $sluzebniCesta, $action)
    {
        parent::__construct('sluzebnicesty/view_formular.php');

        $this->database = $database;
        $this->sluzebniCesta = $sluzebniCesta;
        $this->formAction = $action;
    }


    /**
     * @param Database $database
     * @param int $idPP
     * @return \Ron\Controls\Option[]
     */
    public static function nactiVozidlaOsoby($database, $idPP)
    {
        $params = $database ->createParameters();
        return Option::loadSQL($database,
            'SELECT Vozidlo.RegistracniZnacka, ' .
            ' Vozidlo.RegistracniZnacka ' . $database ->concatenateOperator . " ' ' " . $database ->concatenateOperator . ' Vozidlo.Popis, ' .
            ' Vozidlo.Soukrome, VozidloOsoby.RC' .
            ' FROM PracovniPomer JOIN Vozidlo ON 1 = 1 LEFT OUTER JOIN VozidloOsoby' . // v ON podmince nezvlada parametry, proto pripojuji tabulku Osoba a podminka je ve where
            '   ON VozidloOsoby.RegistracniZnacka = Vozidlo.RegistracniZnacka' .
            '  AND VozidloOsoby.RC = PracovniPomer.RC' .
            ' WHERE PracovniPomer.Id = ' . $params->addParameter((int)$idPP) .
            ' AND (Vozidlo.Soukrome = 0  OR  VozidloOsoby.RC IS NOT NULL)' .
            ' AND (Vozidlo.Aktivni = 1)',
            $params, 0, 1, ' ');
    }


    public function load()
    {
        $this ->menyOptions = Option::loadSQL($this ->database,
            'SELECT KodMeny_ISO FROM Mena WHERE Aktivni = 1 ORDER BY KodMeny_ISO', null, 0, 0);

        $this ->pocatkySC = Option::loadSQL($this ->database,
            'SELECT Kod, Popis FROM MistoSluzebniCesty WHERE Aktivni = 1 AND Pocatek = 1 ORDER BY Popis', null, 0, 1, ' ');

        $this ->cileSC = Option::loadSQL($this ->database,
            'SELECT Kod, Popis FROM MistoSluzebniCesty WHERE Aktivni = 1 AND Cil = 1 ORDER BY Popis', null, 0, 1, ' ');

        $this ->statySC = Option::loadSQL($this ->database,
            'SELECT Kod, Popis FROM Stat WHERE PovolitVeSluzCeste = 1 ORDER BY Popis', null, 0, 1, ' ');

        $emptyRow = ($this ->sluzebniCesta ->ucel  &&  RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_POVINNY_UCEL)) ? null : ' ';
        $this ->ucelySC = Option::loadSQL($this ->database,
            'SELECT Kod, Popis FROM UcelSluzebniCesty WHERE Aktivni = 1 ORDER BY Popis', null, 0, 1, $emptyRow);

        $this ->dopravniProstredky = Option::loadSQL($this ->database,
            'SELECT Kod, Popis FROM DopravniProstredek ORDER BY Popis', null, 0, 1, ' ');

        $this ->zpusobyUctovani = Option::loadSQL($this ->database,
            'SELECT Kod, Popis FROM S_ZpusobVyuctovaniSC ORDER BY Kod', null);

        // vyber osoby
        require_once('adsapp/ronportalcontrols.php');
        $idPP = $this ->sluzebniCesta ->f_PP ? $this ->sluzebniCesta ->f_PP ->idPP : null; // pri vkladani noveho zaznamu neni PP nastaven
        $this ->comboBoxOsoba = new ComboBoxZamestnanec('osoba'); // jmeno promenne
        $this ->comboBoxOsoba ->htmlParams['id'] = 'Osoba';
        $this ->comboBoxOsoba ->loadDataPP($this ->database, time(), time(),
            Prava::vratPrava('sluzebnicesty'), ' ', $idPP, false); // $emptyrow = ' ', $selectedvalue, $vcetneexternich = false

        $this ->comboBoxOsoba ->nastavOsobuDoSession();

        if ( !$this ->sluzebniCesta ->f_PP  &&  $this ->comboBoxOsoba ->idPP ) {
            $this ->sluzebniCesta ->f_PP = new PracovniPomer();
            $this ->sluzebniCesta ->f_PP ->nactiPPPodleId($this ->database, $this ->comboBoxOsoba ->idPP);

            // u nove sluzebni cesty doplni vychozi rozdeleni
            if ((RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI))  &&  RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_ROZDELENI_VYCHOZI)) {
                require_once 'adsapp/rozdeleniosob.php';

                $r = RozdeleniOsob::nactiRozdeleniOsoby($this ->database,
                    $this ->sluzebniCesta ->f_PP, RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI),
                    time(), time(), (RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_ROZDELENI_VYCHOZI) == 2) ? 'Hlavni = 1' : null );

                if ($r) {
                    $this ->sluzebniCesta ->kodTypuRozdeleni = $r[0] ->kodTypuRozdeleni;
                    $this ->sluzebniCesta ->rozdeleni = $r[0] ->kod;
                }
            }

        }

        // vozidla az po osobe
        if (isset($this ->sluzebniCesta->f_PP)) {
            $this->vozidla = self::nactiVozidlaOsoby($this->database, $this->sluzebniCesta->f_PP->idPP);
        }

        require_once('adsapp/rozdeleni.php');
        if (RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI)) {
            // vyber rozdeleni
            $this ->comboBoxesRozdeleni = new ComboBoxesRozdeleni($this ->database, 'Rozdeleni', 'rozdelenisc');
            $this ->comboBoxesRozdeleni ->loadRozdeleni(RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_ROZDELENI_POUZE_VLASTNI),
                $this ->sluzebniCesta ->f_PP,
                RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI),
                $this ->sluzebniCesta ->rozdeleni,
                RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_ROZDELENI_POVINNE));

            $this ->typRozdeleni = new TypRozdeleni();
            $this ->typRozdeleni ->load($this ->database, RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI));
        }
    }


    public function comboBoxMena($name, $value, $params = '')
    {
        ComboBox::renderComboBox($name, $this ->menyOptions, $value,
            ['className' => 'form-control', 'emptyRow' => ' ', 'htmlParams' => $params, 'alwaysShowSelected' => 1]);
    }


    /**
     * @param string $name
     * @param int $id
     * @param int $typRozdeleni
     * @param bool $pouzeVlastni
     * @param string $aktualniHodnota
     * @param bool $povinne
     * @param bool $kod
     * @throws \Ron\RonException
     */
    function showVyberRozdeleni($name, $id, $typRozdeleni, $pouzeVlastni, $aktualniHodnota, $povinne, $kod)
    {
        $params = $this ->database ->createParameters();

        if ( $pouzeVlastni )
        {
            $sql =
                'SELECT DISTINCT Rozdeleni.Kod, Rozdeleni.Popis, Rozdeleni.cssClass ' .
                '  FROM RozdeleniOsob, Rozdeleni'.
                ' WHERE Rozdeleni.KodTypuRozdeleni = ' . $params ->addParameter((int)$typRozdeleni) .
                '   AND (Rozdeleni.DatumZruseni >= ' . $params ->addParameter($this ->database ->timestampToParam(time())) . ' OR Rozdeleni.DatumZruseni IS NULL)'.
                '   AND RozdeleniOsob.KodTypuRozdeleni = Rozdeleni.KodTypuRozdeleni ' .
                '   AND RozdeleniOsob.Rozdeleni = Rozdeleni.Kod ' .
                '   AND (RozdeleniOsob.PlatnostDo >= ' . $params ->addParameter($this ->database ->timestampToParam(time())) . ' OR RozdeleniOsob.PlatnostDo IS NULL)'.
                '   AND RozdeleniOsob.RC = ' . $params->addParameter($this ->sluzebniCesta ->f_PP ->rc) .
                '   AND RozdeleniOsob.OsobniCislo = ' . $params->addParameter($this ->sluzebniCesta ->f_PP ->osobniCislo) .
                '   AND RozdeleniOsob.DatumNastupu = ' . $params ->addParameter($this ->database ->dateToParam($this ->sluzebniCesta ->f_PP ->datumNastupu));
            // ... OR ( Rozdeleni.Kod = '".db_addslashes($hodnota)."'" ... - nepouzivat - je moc pomale !
        } else {
            $sql =
                'SELECT Kod, Popis, cssClass FROM Rozdeleni' .
                ' WHERE KodTypuRozdeleni = ' . $params ->addParameter((int)$typRozdeleni) .
                '   AND ( (' .
                    ($aktualniHodnota != '' ? 'Rozdeleni.Kod = ' . $params->addParameter($aktualniHodnota)  : '0 = 1')   // zvolenou hodnotu zobrazi vzdy - pozor pri volbe "pouze vlastni" je to moc pomale
                . ')' .
                ' OR (' .
                '   (DatumZruseni >= ' . $params ->addParameter($this ->database ->timestampToParam(time())) . ' OR DatumZruseni IS NULL)' .
                ' )' .
                ')';
        }

        $sql .= " AND (cssClass IS NULL  OR  cssClass <> 'hidden') ";

        $isError = MessageManager::getInstance() ->isError($name);

        if ($kod) {
            $combo = new ComboBox($name . '_kod');
            $combo->alwaysShowSelected = isset($aktualniHodnota) && $aktualniHodnota != '';
            $combo->cssClassIndex = 2;
            $combo->captionIndex = 0;
            $combo->emptyRow = (isset($aktualniHodnota) && $aktualniHodnota != '' && $povinne) ? null : ' ';
            $combo->loadData($this->database, $sql . ' ORDER BY Kod', $aktualniHodnota, $params);
            $combo->className .= ' form-control' . ($isError ? ' error' : '');
            $combo->htmlParams = "id='{$id}_kod' data-ron-select2='$name'";
            $combo->render();
        } else {
            $combo = new ComboBox($name);
            $combo->alwaysShowSelected = isset($aktualniHodnota) && $aktualniHodnota != '';
            $combo->cssClassIndex = 2;
            $combo->emptyRow = (isset($aktualniHodnota) && $aktualniHodnota != '' && $povinne) ? null : ' ';
            $combo->loadData($this->database, $sql . ' ORDER BY Popis', $aktualniHodnota, $params);
            $combo->className .= ' form-control' . ($isError ? ' error' : '');
            $combo->htmlParams = "id='{$id}_popis' data-ron-select2='{$name}_kod'";
            $combo->render();
        }
    }


    public function render()
    {
        Model::addData('database', $this->database);
        Model::addData('sluzebniCesta', $this ->sluzebniCesta);
        Model::addData('formAction', $this ->formAction);

        parent::render();
    }


}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/sluzebnicesty/f_sluzebnicesta.php <==
<?php
/**
 * UTF8
 * stanislav.elbl, 02.03.2017
 */

namespace Ron\RonPortal;

use Ron\Controls\ComboBox;
use Ron\Controls\Option;
use Ron\Controls\OptionLoader;
use Ron\DB\Database;
use Ron\MessageManager;
use Ron\MVC\BaseViewObject;
use Ron\MVC\Model;
use RonPortal\Controls\ComboBoxesRozdeleni;
use RonPortal\Controls\ComboBoxZamestnanec;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;
use RonPortal\RozdeleniOsob;
use RonPortal\SluzebniCesty\SluzebniCesta;
use RonPortal\TypRozdeleni;

require_once('ron/controls.php');

class SluzebniCestaFormular extends BaseViewObject
{
    /** @var Database */
    public $database;

    /** @var SluzebniCesta */
    public $sluzebniCesta;

    /** @var string */
    public $formAction;

    /** @var Option[] */
    public $menyOptions;

    /** @var Option[] */
    public $pocatkySC;
    /** @var Option[] */
    public $cileSC;
    /** @var Option[] */
    public $statySC;
    /** @var Option[] */
    public $ucelySC;
    /** @var Option[] */
    public $dopravniProstredky;
    /** @var Option[] */
    public $vozidla;

    /** @var Option[] */
    public $zpusobyUctovani;

    /** @var ComboBoxZamestnanec */
    public $comboBoxOsoba;

    /** @var ComboBoxesRozdeleni */
    public $comboBoxesRozdeleni;

    /** @var TypRozdeleni */
    public $typRozdeleni;


    /**
     * SluzebniCestaFormular constructor.
     * @param Database $database
     * @param SluzebniCesta $sluzebniCesta
     * @param string $action
     */
    public function __construct(Database $database, SluzebniCesta $sluzebniCesta, $action)
    {
        parent::__construct('sluzebnicesty/view_formular.php');

        $this->database = $database;
        $this->sluzebniCesta = $sluzebniCesta;
        $this->formAction = $action;
    }


    /**
     * @param Database $database
     * @param int $idPP
     * @return \Ron\Controls\Option[]
     */
    public static function nactiVozidlaOsoby($database, $idPP)
    {
        $params = $database ->createParameters();
        return (new OptionLoader($database))
            ->setSql(
                'SELECT Vozidlo.RegistracniZnacka, ' .
                ' Vozidlo.RegistracniZnacka ' . $database ->concatenateOperator . " ' ' " . $database ->concatenateOperator . ' Vozidlo.Popis, ' .
                ' Vozidlo.Soukrome, VozidloOsoby.RC' .
                ' FROM PracovniPomer JOIN Vozidlo ON 1 = 1 LEFT OUTER JOIN VozidloOsoby' . // v ON podmince nezvlada parametry, proto pripojuji tabulku Osoba a podminka je ve where
                '   ON VozidloOsoby.RegistracniZnacka = Vozidlo.RegistracniZnacka' .
                '  AND VozidloOsoby.RC = PracovniPomer.RC' .
                ' WHERE PracovniPomer.Id = ' . $params->addParameter((int)$idPP) .
                ' AND (Vozidlo.Soukrome = 0  OR  VozidloOsoby.RC IS NOT NULL)' .
                ' AND (Vozidlo.Aktivni = 1)' .
                ' ORDER BY Vozidlo.RegistracniZnacka',
                $params)
            ->setEmptyValue(' ')
            ->loadData();
    }


    public function load()
    {
        $this ->menyOptions = Option::loadSQL($this ->database,
            'SELECT KodMeny_ISO FROM Mena WHERE Aktivni = 1 ORDER BY KodMeny_ISO', null, 0, 0);

        $this ->pocatkySC = (new OptionLoader($this ->database))
            ->setSql('SELECT Kod, Popis FROM MistoSluzebniCesty WHERE Aktivni = 1 AND Pocatek = 1 ORDER BY Popis')
            ->setEmptyValue(' ')
            ->setTranslationPrefix('db_mistosluzebnicesty_popis_', 0)
            ->loadData();

        $this ->cileSC = (new OptionLoader($this ->database))
            ->setSql('SELECT Kod, Popis FROM MistoSluzebniCesty WHERE Aktivni = 1 AND Cil = 1 ORDER BY Popis')
            ->setEmptyValue(' ')
            ->setTranslationPrefix('db_mistosluzebnicesty_popis_', 0)
            ->loadData();

//        $this ->statySC = Option::loadSQL($this ->database,
//            'SELECT Kod, Popis FROM Stat WHERE PovolitVeSluzCeste = 1 ORDER BY Popis', null, 0, 1, ' ');
        $this ->statySC = (new OptionLoader($this ->database))
            ->setSql('SELECT Kod, Popis FROM Stat WHERE PovolitVeSluzCeste = 1 ORDER BY Popis')
            ->setEmptyValue(' ')
            ->setTranslationPrefix('db_stat_popis_', 0)
            ->loadData();

        $emptyRow = ($this ->sluzebniCesta ->ucel  &&  RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_POVINNY_UCEL)) ? null : ' ';
        $this ->ucelySC = Option::loadSQL($this ->database,
            'SELECT Kod, Popis FROM UcelSluzebniCesty WHERE Aktivni = 1 ORDER BY Popis', null, 0, 1, $emptyRow);

//        $this ->dopravniProstredky = Option::loadSQL($this ->database,
//            'SELECT Kod, Popis FROM DopravniProstredek ORDER BY Popis', null, 0, 1, ' ');
        $this ->dopravniProstredky = (new OptionLoader($this ->database))
            ->setSql('SELECT Kod, Popis FROM DopravniProstredek ORDER BY Popis')
            ->setEmptyValue(' ' )
            ->setTranslationPrefix('db_dopravniprostredek_popis_', 0)
            ->loadData();

        $this ->zpusobyUctovani = Option::loadSQL($this ->database,
            'SELECT Kod, Popis FROM S_ZpusobVyuctovaniSC ORDER BY Kod', null);

        // vyber osoby
        $idPP = $this ->sluzebniCesta ->f_PP ? $this ->sluzebniCesta ->f_PP ->idPP : null; // pri vkladani noveho zaznamu neni PP nastaven
        $this ->comboBoxOsoba = new ComboBoxZamestnanec('osoba'); // jmeno promenne
        $this ->comboBoxOsoba ->htmlParams['id'] = 'Osoba';
        $this ->comboBoxOsoba ->htmlParams['data-max-visible-rows'] = '200';
        $this ->comboBoxOsoba ->loadDataPP($this ->database, time(), time(),
            Prava::vratPrava('sluzebnicesty'), ' ', $idPP, false); // $emptyrow = ' ', $selectedvalue, $vcetneexternich = false

        $this ->comboBoxOsoba ->nastavOsobuDoSession();

        if ( !$this ->sluzebniCesta ->f_PP  &&  $this ->comboBoxOsoba ->idPP ) {
            $this ->sluzebniCesta ->f_PP = new PracovniPomer();
            $this ->sluzebniCesta ->f_PP ->nactiPPPodleId($this ->database, $this ->comboBoxOsoba ->idPP);

            // u nove sluzebni cesty doplni vychozi rozdeleni
            if ((RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI))  &&  RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_ROZDELENI_VYCHOZI)) {

                $r = RozdeleniOsob::nactiRozdeleniOsoby($this ->database,
                    $this ->sluzebniCesta ->f_PP, RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI),
                    time(), time(), (RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_ROZDELENI_VYCHOZI) == 2) ? 'Hlavni = 1' : null );

                if ($r) {
                    $this ->sluzebniCesta ->kodTypuRozdeleni = $r[0] ->kodTypuRozdeleni;
                    $this ->sluzebniCesta ->rozdeleni = $r[0] ->kod;
                }
            }

        }

        // vozidla az po osobe
        if (isset($this ->sluzebniCesta->f_PP)) {
            $this->vozidla = self::nactiVozidlaOsoby($this->database, $this->sluzebniCesta->f_PP->idPP);
        }

        if (RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI)) {
            // vyber rozdeleni
            $this ->comboBoxesRozdeleni = new ComboBoxesRozdeleni($this ->database, 'Rozdeleni', 'rozdelenisc');
            $this ->comboBoxesRozdeleni ->loadRozdeleni(RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_ROZDELENI_POUZE_VLASTNI),
                $this ->sluzebniCesta ->f_PP,
                RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI),
                $this ->sluzebniCesta ->rozdeleni,
                RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_ROZDELENI_POVINNE));

            $this ->typRozdeleni = new TypRozdeleni();
            $this ->typRozdeleni ->load($this ->database, RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_TYP_ROZDELENI));
        }
    }


    public function comboBoxMena($name, $value, $params = '')
    {
        ComboBox::renderComboBox($name, $this ->menyOptions, $value,
            ['className' => 'form-control', 'emptyRow' => ' ', 'htmlParams' => $params, 'alwaysShowSelected' => 1]);
    }


    /**
     * @param string $name
     * @param int $id
     * @param int $typRozdeleni
     * @param bool $pouzeVlastni
     * @param string $aktualniHodnota
     * @param bool $povinne
     * @param bool $kod
     * @throws \Ron\RonException
     */
    function showVyberRozdeleni($name, $id, $typRozdeleni, $pouzeVlastni, $aktualniHodnota, $povinne, $kod)
    {
        $params = $this ->database ->createParameters();

        if ( $pouzeVlastni ) {
            $sql =
                'SELECT DISTINCT Rozdeleni.Kod, Rozdeleni.Popis, Rozdeleni.cssClass ' .
                '  FROM RozdeleniOsob, Rozdeleni'.
                ' WHERE Rozdeleni.KodTypuRozdeleni = ' . $params ->addParameter((int)$typRozdeleni) .
                '   AND (Rozdeleni.DatumZruseni >= ' . $params ->addParameter($this ->database ->timestampToParam(time())) . ' OR Rozdeleni.DatumZruseni IS NULL)'.
                '   AND RozdeleniOsob.KodTypuRozdeleni = Rozdeleni.KodTypuRozdeleni ' .
                '   AND RozdeleniOsob.Rozdeleni = Rozdeleni.Kod ' .
                '   AND (RozdeleniOsob.PlatnostDo >= ' . $params ->addParameter($this ->database ->timestampToParam(time())) . ' OR RozdeleniOsob.PlatnostDo IS NULL)'.
                '   AND RozdeleniOsob.RC = ' . $params->addParameter($this ->sluzebniCesta ->f_PP ->rc) .
                '   AND RozdeleniOsob.OsobniCislo = ' . $params->addParameter($this ->sluzebniCesta ->f_PP ->osobniCislo) .
                '   AND RozdeleniOsob.DatumNastupu = ' . $params ->addParameter($this ->database ->dateToParam($this ->sluzebniCesta ->f_PP ->datumNastupu));
            // ... OR ( Rozdeleni.Kod = '".db_addslashes($hodnota)."'" ... - nepouzivat - je moc pomale !
        } else {
            $sql =
                'SELECT Kod, Popis, cssClass FROM Rozdeleni' .
                ' WHERE KodTypuRozdeleni = ' . $params ->addParameter((int)$typRozdeleni) .
                '   AND ( (' .
                    ($aktualniHodnota != '' ? 'Rozdeleni.Kod = ' . $params->addParameter($aktualniHodnota)  : '0 = 1')   // zvolenou hodnotu zobrazi vzdy - pozor pri volbe "pouze vlastni" je to moc pomale
                . ')' .
                ' OR (' .
                '   (DatumZruseni >= ' . $params ->addParameter($this ->database ->timestampToParam(time())) . ' OR DatumZruseni IS NULL)' .
                ' )' .
                ')';
        }

        $sql .= " AND (cssClass IS NULL  OR  cssClass <> 'hidden') ";

        $isError = MessageManager::getInstance() ->isError($name);

        if ($kod) {
            $combo = new ComboBox($name . '_kod');
            $combo->alwaysShowSelected = isset($aktualniHodnota) && $aktualniHodnota != '';
            $combo->cssClassIndex = 2;
            $combo->captionIndex = 0;
            $combo->attrIndexes = ['data-popis' => 1];
            $combo->titleIndex = 1;
            $combo->emptyRow = (isset($aktualniHodnota) && $aktualniHodnota != '' && $povinne) ? null : ' ';
            $combo->loadData($this->database, $sql . ' ORDER BY Kod', $aktualniHodnota, $params);
            $combo->className .= ' form-control ronselect' . ($isError ? ' error' : '');
            $combo->htmlParams = [
                'id' => "{$id}_kod",
                'data-ron-select2' => $name,
                'data-columns' => 'value;popis',
                'data-drop-down-align' => 'right'];
            $combo->render();
        } else {
            $combo = new ComboBox($name);
            $combo->alwaysShowSelected = isset($aktualniHodnota) && $aktualniHodnota != '';
            $combo->cssClassIndex = 2;
            $combo->emptyRow = (isset($aktualniHodnota) && $aktualniHodnota != '' && $povinne) ? null : ' ';
            $combo->loadData($this->database, $sql . ' ORDER BY Popis', $aktualniHodnota, $params);
            $combo->className .= ' form-control ronselect' . ($isError ? ' error' : '');
            $combo->htmlParams = ['id' => "{$id}_popis", 'data-ron-select2' => "{$name}_kod"];
            $combo->render();
        }
    }


    public function render()
    {
        Model::addData('database', $this->database);
        Model::addData('sluzebniCesta', $this ->sluzebniCesta);
        Model::addData('formAction', $this ->formAction);

        parent::render();
    }


}
